# qhub-mcp

## Development

Create a virtual environment:

```bash
uv venv
uv sync -U

source .venv/bin/activate

pytest
```

Build the distribution:

```bash
uv build
```

Upload to PyPI:

```bash
uv publish
```
